function f = shEvalFunctionL( band, coeffs, lambda) 
%
% f = shEvalFunctionL( band, coeffs, lambda) 
%
% Evaluate the l-th Spherical Harmonics band of the function f 
% represented by \a coeffs at the point lambda = (theta,phi). 
% The function f can have different channels which have to correspond to 
% different rows of \a coeffs.
%
% @param  band    Spherical Harmonics band to evaluate.
% @param  coeffs  Spherical Harmonics representation of the function f to
%                 evaluate (the coefficients can either be all the 
%                 coefficients of a signal or only the coefficients for 
%                 band l).
% @param  lambda  Point on S^2 where to evaluate f.

  % function values to compute
  f = zeros( size( coeffs, 1), size( lambda,1));

  % determine if coeffs is a complete basis function vector across multiple
  % bands or only contains the coefficients in band l
  if( (2*band+1) == size(coeffs,2))
    index_base = band+1;
  else
    index_base = band*(band+1)+1;
  end
    
  % sum over all SH basis functions in the band
  for( m = -band : band)
    index = index_base + m;
      f = f + coeffs(:,index) * shEval(band, m, lambda(:,1), lambda(:,2)); 
  end

end

